Learn R Programming

CDMConnector (version 2.7.0)

CDMConnector-package: CDMConnector: Connect to an OMOP Common Data Model

Description

logo

Provides tools for working with observational health data in the Observational Medical Outcomes Partnership (OMOP) Common Data Model format with a pipe friendly syntax. Common data model database table references are stored in a single compound object along with metadata.

Arguments

Author

Maintainer: Ger Inberg g.inberg@erasmusmc.nl (ORCID)

Authors:

See Also