cdmDisconnect.db_cdm: Disconnect the connection of the cdm object

View source: R/dbSource.R

cdmDisconnect.db_cdmR Documentation

Disconnect the connection of the cdm object

Description

This function will disconnect from the database as well as drop "temporary" tables that were created on database systems that do not support actual temporary tables. Currently temp tables are emulated on Spark/Databricks systems.

Usage

## S3 method for class 'db_cdm'
cdmDisconnect(cdm, dropPrefixTables = FALSE, ...)

Arguments

cdm

cdm reference

dropPrefixTables

Whether to drop tables in the writeSchema prefixed with writePrefix

...

Not used. Included for compatibility with generic.


CDMConnector documentation built on April 3, 2026, 9:09 a.m.