dbSource: Create a source for a cdm in a database.

View source: R/dbSource.R

dbSourceR Documentation

Create a source for a cdm in a database.

Description

Create a source for a cdm in a database.

Usage

dbSource(con, writeSchema)

Arguments

con

Connection to a database.

writeSchema

Schema where cohort tables are. If provided must have read and write access to it. If NULL the cdm will be created without a write_schema.


CDMConnector documentation built on April 3, 2026, 9:09 a.m.